====
Name
====

The following methods are available under the `expr.name` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Expr.name.keep
    Expr.name.map
    Expr.name.map_fields
    Expr.name.prefix
    Expr.name.prefix_fields
    Expr.name.suffix
    Expr.name.suffix_fields
    Expr.name.to_lowercase
    Expr.name.to_uppercase
